<?php
session_start();
if (!isset($_SESSION['user_id'])) {
    header('Location: index.php');
    exit;
}

include 'includes/db_connect.php';

// 获取统计数据
$totalIncome = $pdo->query("SELECT SUM(amount) as total FROM income")->fetch()['total'];
$totalExpense = $pdo->query("SELECT SUM(amount) as total FROM expenses")->fetch()['total'];
$totalWorkers = $pdo->query("SELECT COUNT(*) as total FROM workers")->fetch()['total'];
$totalProjects = $pdo->query("SELECT COUNT(*) as total FROM projects")->fetch()['total'];

$netBalance = $totalIncome - $totalExpense;
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>工地记账系统 - 控制面板</title>
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <header>
        <div class="container">
            <div id="branding">
                <h1>工地记账系统</h1>
            </div>
            <nav>
                <ul>
                    <li class="current"><a href="dashboard.php">控制面板</a></li>
                    <li><a href="income.php">收入</a></li>
                    <li><a href="expense.php">支出</a></li>
                    <li><a href="workers.php">工人</a></li>
                    <li><a href="projects.php">项目</a></li>
                    <li><a href="reports.php">报表</a></li>
                    <li><a href="logout.php">退出</a></li>
                </ul>
            </nav>
        </div>
    </header>

    <div class="container">
        <h2>欢迎, <?php echo $_SESSION['username']; ?>!</h2>
        
        <div style="display: flex; flex-wrap: wrap; justify-content: space-between;">
            <div class="dashboard-card" style="flex: 1; min-width: 200px;">
                <h3>总收入</h3>
                <div class="amount">¥<?php echo number_format($totalIncome, 2); ?></div>
            </div>
            
            <div class="dashboard-card" style="flex: 1; min-width: 200px;">
                <h3>总支出</h3>
                <div class="amount">¥<?php echo number_format($totalExpense, 2); ?></div>
            </div>
            
            <div class="dashboard-card" style="flex: 1; min-width: 200px;">
                <h3>净余额</h3>
                <div class="amount">¥<?php echo number_format($netBalance, 2); ?></div>
            </div>
            
            <div class="dashboard-card" style="flex: 1; min-width: 200px;">
                <h3>工人数量</h3>
                <div class="amount"><?php echo $totalWorkers; ?></div>
            </div>
            
            <div class="dashboard-card" style="flex: 1; min-width: 200px;">
                <h3>项目数量</h3>
                <div class="amount"><?php echo $totalProjects; ?></div>
            </div>
        </div>
        
        <h3>最近收入</h3>
        <?php
        $recentIncome = $pdo->query("SELECT * FROM income ORDER BY date DESC LIMIT 5")->fetchAll();
        if ($recentIncome): ?>
            <table>
                <tr>
                    <th>日期</th>
                    <th>项目</th>
                    <th>金额</th>
                    <th>描述</th>
                </tr>
                <?php foreach ($recentIncome as $income): ?>
                    <tr>
                        <td><?php echo $income['date']; ?></td>
                        <td><?php 
                            $project = $pdo->query("SELECT name FROM projects WHERE id = " . $income['project_id'])->fetch();
                            echo $project ? $project['name'] : '无项目';
                        ?></td>
                        <td>¥<?php echo number_format($income['amount'], 2); ?></td>
                        <td><?php echo $income['description']; ?></td>
                    </tr>
                <?php endforeach; ?>
            </table>
        <?php else: ?>
            <p>暂无收入记录</p>
        <?php endif; ?>
        
        <h3>最近支出</h3>
        <?php
        $recentExpense = $pdo->query("SELECT * FROM expenses ORDER BY date DESC LIMIT 5")->fetchAll();
        if ($recentExpense): ?>
            <table>
                <tr>
                    <th>日期</th>
                    <th>类别</th>
                    <th>金额</th>
                    <th>描述</th>
                </tr>
                <?php foreach ($recentExpense as $expense): ?>
                    <tr>
                        <td><?php echo $expense['date']; ?></td>
                        <td><?php echo $expense['category']; ?></td>
                        <td>¥<?php echo number_format($expense['amount'], 2); ?></td>
                        <td><?php echo $expense['description']; ?></td>
                    </tr>
                <?php endforeach; ?>
            </table>
        <?php else: ?>
            <p>暂无支出记录</p>
        <?php endif; ?>
    </div>
    
    <script src="js/main.js"></script>
</body>
</html>