<?php
session_start();
if (!isset($_SESSION['user_id'])) {
    header('Location: index.php');
    exit;
}

include 'includes/db_connect.php';

// 添加支出记录
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['add_expense'])) {
    $category = $_POST['category'];
    $amount = $_POST['amount'];
    $date = $_POST['date'];
    $description = $_POST['description'];
    
    $stmt = $pdo->prepare("INSERT INTO expenses (category, amount, date, description) VALUES (?, ?, ?, ?)");
    $stmt->execute([$category, $amount, $date, $description]);
    
    header('Location: expense.php');
    exit;
}

// 删除支出记录
if (isset($_GET['delete'])) {
    $id = $_GET['delete'];
    $pdo->prepare("DELETE FROM expenses WHERE id = ?")->execute([$id]);
    header('Location: expense.php');
    exit;
}

// 获取支出记录
$expenses = $pdo->query("SELECT * FROM expenses ORDER BY date DESC")->fetchAll();
$categories = ['材料费', '人工费', '设备租赁', '运输费', '餐饮费', '其他'];
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>工地记账系统 - 支出记录</title>
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <header>
        <div class="container">
            <div id="branding">
                <h1>工地记账系统</h1>
            </div>
            <nav>
                <ul>
                    <li><a href="dashboard.php">控制面板</a></li>
                    <li><a href="income.php">收入</a></li>
                    <li class="current"><a href="expense.php">支出</a></li>
                    <li><a href="workers.php">工人</a></li>
                    <li><a href="projects.php">项目</a></li>
                    <li><a href="reports.php">报表</a></li>
                    <li><a href="logout.php">退出</a></li>
                </ul>
            </nav>
        </div>
    </header>

    <div class="container">
        <h2>支出记录</h2>
        
        <form method="post">
            <h3>添加新支出</h3>
            <label for="category">类别</label>
            <select id="category" name="category" required>
                <option value="">选择类别</option>
                <?php foreach ($categories as $cat): ?>
                    <option value="<?php echo $cat; ?>"><?php echo $cat; ?></option>
                <?php endforeach; ?>
            </select>
            
            <label for="amount">金额 (¥)</label>
            <input type="number" id="amount" name="amount" step="0.01" min="0" required>
            
            <label for="date">日期</label>
            <input type="date" id="date" name="date" required>
            
            <label for="description">描述</label>
            <textarea id="description" name="description" rows="3"></textarea>
            
            <input type="submit" name="add_expense" value="添加支出">
        </form>
        
        <h3>支出记录列表</h3>
        <?php if ($expenses): ?>
            <table>
                <tr>
                    <th>日期</th>
                    <th>类别</th>
                    <th>金额</th>
                    <th>描述</th>
                    <th>操作</th>
                </tr>
                <?php foreach ($expenses as $expense): ?>
                    <tr>
                        <td><?php echo $expense['date']; ?></td>
                        <td><?php echo $expense['category']; ?></td>
                        <td>¥<?php echo number_format($expense['amount'], 2); ?></td>
                        <td><?php echo $expense['description']; ?></td>
                        <td>
                            <a href="expense.php?delete=<?php echo $expense['id']; ?>" class="delete-btn" style="color: red;">删除</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </table>
        <?php else: ?>
            <p>暂无支出记录</p>
        <?php endif; ?>
    </div>
    
    <script src="js/main.js"></script>
</body>
</html>