<?php
session_start();
if (!isset($_SESSION['user_id'])) {
    header('Location: index.php');
    exit;
}

include 'includes/db_connect.php';

// 添加收入记录
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['add_income'])) {
    $project_id = $_POST['project_id'];
    $amount = $_POST['amount'];
    $date = $_POST['date'];
    $description = $_POST['description'];
    
    $stmt = $pdo->prepare("INSERT INTO income (project_id, amount, date, description) VALUES (?, ?, ?, ?)");
    $stmt->execute([$project_id, $amount, $date, $description]);
    
    header('Location: income.php');
    exit;
}

// 删除收入记录
if (isset($_GET['delete'])) {
    $id = $_GET['delete'];
    $pdo->prepare("DELETE FROM income WHERE id = ?")->execute([$id]);
    header('Location: income.php');
    exit;
}

// 获取所有项目和收入记录
$projects = $pdo->query("SELECT * FROM projects")->fetchAll();
$incomes = $pdo->query("SELECT * FROM income ORDER BY date DESC")->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>工地记账系统 - 收入记录</title>
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <header>
        <div class="container">
            <div id="branding">
                <h1>工地记账系统</h1>
            </div>
            <nav>
                <ul>
                    <li><a href="dashboard.php">控制面板</a></li>
                    <li class="current"><a href="income.php">收入</a></li>
                    <li><a href="expense.php">支出</a></li>
                    <li><a href="workers.php">工人</a></li>
                    <li><a href="projects.php">项目</a></li>
                    <li><a href="reports.php">报表</a></li>
                    <li><a href="logout.php">退出</a></li>
                </ul>
            </nav>
        </div>
    </header>

    <div class="container">
        <h2>收入记录</h2>
        
        <form method="post">
            <h3>添加新收入</h3>
            <label for="project_id">项目</label>
            <select id="project_id" name="project_id" required>
                <option value="">选择项目</option>
                <?php foreach ($projects as $project): ?>
                    <option value="<?php echo $project['id']; ?>"><?php echo $project['name']; ?></option>
                <?php endforeach; ?>
            </select>
            
            <label for="amount">金额 (¥)</label>
            <input type="number" id="amount" name="amount" step="0.01" min="0" required>
            
            <label for="date">日期</label>
            <input type="date" id="date" name="date" required>
            
            <label for="description">描述</label>
            <textarea id="description" name="description" rows="3"></textarea>
            
            <input type="submit" name="add_income" value="添加收入">
        </form>
        
        <h3>收入记录列表</h3>
        <?php if ($incomes): ?>
            <table>
                <tr>
                    <th>日期</th>
                    <th>项目</th>
                    <th>金额</th>
                    <th>描述</th>
                    <th>操作</th>
                </tr>
                <?php foreach ($incomes as $income): ?>
                    <tr>
                        <td><?php echo $income['date']; ?></td>
                        <td><?php 
                            $project = $pdo->query("SELECT name FROM projects WHERE id = " . $income['project_id'])->fetch();
                            echo $project ? $project['name'] : '无项目';
                        ?></td>
                        <td>¥<?php echo number_format($income['amount'], 2); ?></td>
                        <td><?php echo $income['description']; ?></td>
                        <td>
                            <a href="income.php?delete=<?php echo $income['id']; ?>" class="delete-btn" style="color: red;">删除</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </table>
        <?php else: ?>
            <p>暂无收入记录</p>
        <?php endif; ?>
    </div>
    
    <script src="js/main.js"></script>
</body>
</html>