<?php
session_start();
if (!isset($_SESSION['user_id'])) {
    header('Location: index.php');
    exit;
}

include 'includes/db_connect.php';

// 添加项目
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['add_project'])) {
    $name = $_POST['name'];
    $location = $_POST['location'];
    $start_date = $_POST['start_date'];
    $end_date = $_POST['end_date'];
    $description = $_POST['description'];
    
    $stmt = $pdo->prepare("INSERT INTO projects (name, location, start_date, end_date, description) VALUES (?, ?, ?, ?, ?)");
    $stmt->execute([$name, $location, $start_date, $end_date, $description]);
    
    header('Location: projects.php');
    exit;
}

// 删除项目
if (isset($_GET['delete'])) {
    $id = $_GET['delete'];
    $pdo->prepare("DELETE FROM projects WHERE id = ?")->execute([$id]);
    header('Location: projects.php');
    exit;
}

// 获取所有项目
$projects = $pdo->query("SELECT * FROM projects ORDER BY start_date DESC")->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>工地记账系统 - 项目管理</title>
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <header>
        <div class="container">
            <div id="branding">
                <h1>工地记账系统</h1>
            </div>
            <nav>
                <ul>
                    <li><a href="dashboard.php">控制面板</a></li>
                    <li><a href="income.php">收入</a></li>
                    <li><a href="expense.php">支出</a></li>
                    <li><a href="workers.php">工人</a></li>
                    <li class="current"><a href="projects.php">项目</a></li>
                    <li><a href="reports.php">报表</a></li>
                    <li><a href="logout.php">退出</a></li>
                </ul>
            </nav>
        </div>
    </header>

    <div class="container">
        <h2>项目管理</h2>
        
        <form method="post">
            <h3>添加新项目</h3>
            <label for="name">项目名称</label>
            <input type="text" id="name" name="name" required>
            
            <label for="location">项目地点</label>
            <input type="text" id="location" name="location">
            
            <label for="start_date">开始日期</label>
            <input type="date" id="start_date" name="start_date" required>
            
            <label for="end_date">结束日期</label>
            <input type="date" id="end_date" name="end_date">
            
            <label for="description">项目描述</label>
            <textarea id="description" name="description" rows="3"></textarea>
            
            <input type="submit" name="add_project" value="添加项目">
        </form>
        
        <h3>项目列表</h3>
        <?php if ($projects): ?>
            <table>
                <tr>
                    <th>项目名称</th>
                    <th>地点</th>
                    <th>开始日期</th>
                    <th>结束日期</th>
                    <th>操作</th>
                </tr>
                <?php foreach ($projects as $project): ?>
                    <tr>
                        <td><?php echo $project['name']; ?></td>
                        <td><?php echo $project['location']; ?></td>
                        <td><?php echo $project['start_date']; ?></td>
                        <td><?php echo $project['end_date']; ?></td>
                        <td>
                            <a href="projects.php?delete=<?php echo $project['id']; ?>" class="delete-btn" style="color: red;">删除</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </table>
        <?php else: ?>
            <p>暂无项目记录</p>
        <?php endif; ?>
    </div>
    
    <script src="js/main.js"></script>
</body>
</html>