<?php
session_start();
if (!isset($_SESSION['user_id'])) {
    header('Location: index.php');
    exit;
}

include 'includes/db_connect.php';

// 添加工人
if ($_SERVER['REQUEST_METHOD'] == 'POST' && isset($_POST['add_worker'])) {
    $name = $_POST['name'];
    $phone = $_POST['phone'];
    $id_number = $_POST['id_number'];
    $position = $_POST['position'];
    $daily_wage = $_POST['daily_wage'];
    
    $stmt = $pdo->prepare("INSERT INTO workers (name, phone, id_number, position, daily_wage) VALUES (?, ?, ?, ?, ?)");
    $stmt->execute([$name, $phone, $id_number, $position, $daily_wage]);
    
    header('Location: workers.php');
    exit;
}

// 删除工人
if (isset($_GET['delete'])) {
    $id = $_GET['delete'];
    $pdo->prepare("DELETE FROM workers WHERE id = ?")->execute([$id]);
    header('Location: workers.php');
    exit;
}

// 获取所有工人
$workers = $pdo->query("SELECT * FROM workers ORDER BY name")->fetchAll();
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>工地记账系统 - 工人管理</title>
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <header>
        <div class="container">
            <div id="branding">
                <h1>工地记账系统</h1>
            </div>
            <nav>
                <ul>
                    <li><a href="dashboard.php">控制面板</a></li>
                    <li><a href="income.php">收入</a></li>
                    <li><a href="expense.php">支出</a></li>
                    <li class="current"><a href="workers.php">工人</a></li>
                    <li><a href="projects.php">项目</a></li>
                    <li><a href="reports.php">报表</a></li>
                    <li><a href="logout.php">退出</a></li>
                </ul>
            </nav>
        </div>
    </header>

    <div class="container">
        <h2>工人管理</h2>
        
        <form method="post">
            <h3>添加工人</h3>
            <label for="name">姓名</label>
            <input type="text" id="name" name="name" required>
            
            <label for="phone">电话</label>
            <input type="text" id="phone" name="phone">
            
            <label for="id_number">身份证号</label>
            <input type="text" id="id_number" name="id_number">
            
            <label for="position">职位</label>
            <input type="text" id="position" name="position">
            
            <label for="daily_wage">日工资 (¥)</label>
            <input type="number" id="daily_wage" name="daily_wage" step="0.01" min="0">
            
            <input type="submit" name="add_worker" value="添加工人">
        </form>
        
        <h3>工人列表</h3>
        <?php if ($workers): ?>
            <table>
                <tr>
                    <th>姓名</th>
                    <th>电话</th>
                    <th>身份证号</th>
                    <th>职位</th>
                    <th>日工资</th>
                    <th>操作</th>
                </tr>
                <?php foreach ($workers as $worker): ?>
                    <tr>
                        <td><?php echo $worker['name']; ?></td>
                        <td><?php echo $worker['phone']; ?></td>
                        <td><?php echo $worker['id_number']; ?></td>
                        <td><?php echo $worker['position']; ?></td>
                        <td>¥<?php echo number_format($worker['daily_wage'], 2); ?></td>
                        <td>
                            <a href="workers.php?delete=<?php echo $worker['id']; ?>" class="delete-btn" style="color: red;">删除</a>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </table>
        <?php else: ?>
            <p>暂无工人记录</p>
        <?php endif; ?>
    </div>
    
    <script src="js/main.js"></script>
</body>
</html>